"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListPolicies = void 0;
const ListPoliciesCommand_1 = require("../commands/ListPoliciesCommand");
const IoTClient_1 = require("../IoTClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListPoliciesCommand_1.ListPoliciesCommand(input), ...args);
};
async function* paginateListPolicies(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.marker = token;
        input["pageSize"] = config.pageSize;
        if (config.client instanceof IoTClient_1.IoTClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected IoT | IoTClient");
        }
        yield page;
        const prevToken = token;
        token = page.nextMarker;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateListPolicies = paginateListPolicies;
