"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListStreams = void 0;
const ListStreamsCommand_1 = require("../commands/ListStreamsCommand");
const IoTClient_1 = require("../IoTClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListStreamsCommand_1.ListStreamsCommand(input), ...args);
};
async function* paginateListStreams(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.nextToken = token;
        input["maxResults"] = config.pageSize;
        if (config.client instanceof IoTClient_1.IoTClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected IoT | IoTClient");
        }
        yield page;
        const prevToken = token;
        token = page.nextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateListStreams = paginateListStreams;
