import { EndpointParameterInstructions } from "@smithy/middleware-endpoint";
import { Command as $Command } from "@smithy/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { DescribeManagedJobTemplateRequest, DescribeManagedJobTemplateResponse } from "../models/models_1";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link DescribeManagedJobTemplateCommand}.
 */
export interface DescribeManagedJobTemplateCommandInput extends DescribeManagedJobTemplateRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeManagedJobTemplateCommand}.
 */
export interface DescribeManagedJobTemplateCommandOutput extends DescribeManagedJobTemplateResponse, __MetadataBearer {
}
/**
 * @public
 * <p>View details of a managed job template.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, DescribeManagedJobTemplateCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, DescribeManagedJobTemplateCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // DescribeManagedJobTemplateRequest
 *   templateName: "STRING_VALUE", // required
 *   templateVersion: "STRING_VALUE",
 * };
 * const command = new DescribeManagedJobTemplateCommand(input);
 * const response = await client.send(command);
 * // { // DescribeManagedJobTemplateResponse
 * //   templateName: "STRING_VALUE",
 * //   templateArn: "STRING_VALUE",
 * //   description: "STRING_VALUE",
 * //   templateVersion: "STRING_VALUE",
 * //   environments: [ // Environments
 * //     "STRING_VALUE",
 * //   ],
 * //   documentParameters: [ // DocumentParameters
 * //     { // DocumentParameter
 * //       key: "STRING_VALUE",
 * //       description: "STRING_VALUE",
 * //       regex: "STRING_VALUE",
 * //       example: "STRING_VALUE",
 * //       optional: true || false,
 * //     },
 * //   ],
 * //   document: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param DescribeManagedJobTemplateCommandInput - {@link DescribeManagedJobTemplateCommandInput}
 * @returns {@link DescribeManagedJobTemplateCommandOutput}
 * @see {@link DescribeManagedJobTemplateCommandInput} for command's `input` shape.
 * @see {@link DescribeManagedJobTemplateCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Internal error from the service that indicates an unexpected error or that the service
 *             is unavailable.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 */
export declare class DescribeManagedJobTemplateCommand extends $Command<DescribeManagedJobTemplateCommandInput, DescribeManagedJobTemplateCommandOutput, IoTClientResolvedConfig> {
    readonly input: DescribeManagedJobTemplateCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    /**
     * @public
     */
    constructor(input: DescribeManagedJobTemplateCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: IoTClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeManagedJobTemplateCommandInput, DescribeManagedJobTemplateCommandOutput>;
    /**
     * @internal
     */
    private serialize;
    /**
     * @internal
     */
    private deserialize;
}
